export interface AllOptions {
    allClearResetTime: number;
    connectTimeout: number;
    constructor: new (url: string, protocols?: string | string[]) => WebSocket;
    debug: boolean;
    minReconnectDelay: number;
    maxReconnectDelay: number;
    maxReconnectAttempts: number;
    reconnectBackoffFactor: number;
    shouldReconnect(closeEvent: CloseEvent): boolean;
}
export declare type Options = Partial<AllOptions>;
export default class SturdyWebSocket implements WebSocket {
    readonly url: string;
    static readonly DEFAULT_OPTIONS: AllOptions;
    static readonly CONNECTING: number;
    static readonly OPEN: number;
    static readonly CLOSING: number;
    static readonly CLOSED: number;
    onclose: (event: CloseEvent) => void;
    onerror: (event: Event) => void;
    onmessage: (event: MessageEvent) => void;
    onopen: (event: Event) => void;
    ondown: (event: CloseEvent) => void;
    onreopen: (event: Event) => void;
    readonly CONNECTING: number;
    readonly OPEN: number;
    readonly CLOSING: number;
    readonly CLOSED: number;
    private readonly protocols?;
    private readonly options;
    private ws?;
    private hasBeenOpened;
    private isClosed;
    private messageBuffer;
    private nextRetryTime;
    private reconnectCount;
    private allClearTimeoutId?;
    private connectTimeoutId?;
    private _binaryType?;
    private lastKnownExtensions;
    private lastKnownProtocol;
    private readonly listeners;
    constructor(url: string, options?: Options);
    constructor(url: string, protocols: string | string[] | undefined, options?: Options);
    binaryType: string;
    readonly bufferedAmount: number;
    readonly extensions: string;
    readonly protocol: string;
    readonly readyState: number;
    close(code?: number, reason?: string): void;
    send(data: any): void;
    addEventListener<K extends keyof WebSocketEventMap>(type: K, listener: (this: WebSocket, event: WebSocketEventMap[K]) => void): void;
    dispatchEvent(event: Event): boolean;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject): void;
    private openNewWebSocket();
    private handleOpen(event);
    private handleMessage(event);
    private handleClose(event);
    private handleError(event);
    private reconnect();
    private shutdown();
    private clearAllTimeouts();
    private clearConnectTimeout();
    private clearAllClearTimeout();
    private dispatchEventOfType(type, event);
    private callListener(listener, event);
    private debugLog(message);
}
